==> haskell-torrent-10000.1.3-124.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 torrent
version:              10000.1.3
visibility:           public
id:                   torrent-10000.1.3-3MLanMskkfJ7dsjP5LVKiD
key:                  torrent-10000.1.3-3MLanMskkfJ7dsjP5LVKiD
license:              BSD-3-Clause
copyright:            2005-2007, Lemmih
maintainer:           Joey Hess <id@joeyh.name>
author:               Lemmih <lemmih@gmail.com>
synopsis:             BitTorrent file parser and generater
category:             Network
abi:                  7382b65f2b063077cc1f70e64cd10acd
exposed:              True
exposed-modules:      Data.Torrent Data.Torrent.Scrape
import-dirs:          /usr/lib/ghc-9.6.6/site-local/torrent-10000.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/torrent-10000.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/torrent-10000.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-torrent
hs-libraries:         HStorrent-10000.1.3-3MLanMskkfJ7dsjP5LVKiD
depends:
    base-4.18.2.1 bencode-0.6.1.1-FSfVHMAhZ8d6YXjXioGXFW binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7 filepath-1.4.300.1
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt

haddock-interfaces:   /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html:         /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-torrent-10000.1.3-125-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 torrent
version:              10000.1.3
visibility:           public
id:                   torrent-10000.1.3-DoC9dKgaHuGKfHTIDQ5vmX
key:                  torrent-10000.1.3-DoC9dKgaHuGKfHTIDQ5vmX
license:              BSD-3-Clause
copyright:            2005-2007, Lemmih
maintainer:           Joey Hess <id@joeyh.name>
author:               Lemmih <lemmih@gmail.com>
synopsis:             BitTorrent file parser and generater
category:             Network
abi:                  112199e97660b5d33e46daeebb700ba9
exposed:              True
exposed-modules:      Data.Torrent Data.Torrent.Scrape
import-dirs:          /usr/lib/ghc-9.6.6/site-local/torrent-10000.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/torrent-10000.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/torrent-10000.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-torrent
hs-libraries:         HStorrent-10000.1.3-DoC9dKgaHuGKfHTIDQ5vmX
depends:
    base-4.18.2.1 bencode-0.6.1.1-4DKqNqBvEl1EcuJj9jPIgZ binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7 filepath-1.4.300.1
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp

haddock-interfaces:   /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html:         /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
